/* New Chassis Plate 

History:
--------
v1: Erster Wurf...alles noch sehr rudimentär, unklar, ob die Maße stimmen
v3: Servohalter..
v7: Introducing Chassis_Globals_v1.scad.
v8: Shortened by 10mm. (Overall len was 141 is now 131mm). Changed in Chassis_Globals_v2.scad
v9: Nochmal 2mm kürzer. Changed in Chassis_Globals_v3.scad
v10: More stiffeners. Front end is bending too much, especially in summer. PLA has its disadvantages...

ToDo:
-----
- korrekte Länge
- Wishbone-Mount-Löcher


*/

/* Modules */
include <Chassis_Globals_v3.scad>;
include <../../Modules/Module_Geometrical_Objects.scad>;
include <../../Modules/Module_Really_Rounded_Cube.scad>;

/* Globals */
$fn=23;
//$fn=50;

/* MOVED TO Chassis_Globals_v1.scad!
gStiffenerStrength=8.0;
gBatterySizeLength=140; 
gPlateWidthFront=gBatterySizeLength + 2*gStiffenerStrength + 2.3; 
gPlateThickness=3.0;
gPlateLengthFront=42.0+45; // s. gStiffenerOverlap im Rear
gStiffenerOverlap=53; // wie weit er auf das vordere Teil des hinteren Teils überlappt :-)
gStiffenerLength=gPlateLengthFront+gStiffenerOverlap; // s. gPlateLengthFront im Rear //v1: 3*23.2323232323; // TODO: X-Len 
gNoseLength=59-5;
gNoseWidth=30; // TBD
*/
echo("Overall length (front part): ", gNoseLength+gPlateLengthFront);


/* Vorbereitungen fürs Kettenmaß */
//lRearXMax=-gPlateLengthRear;
//lRearYMax=gPlateWidthRear/2;
lFrontYMax=gPlateWidthFront/2;

/* (Un)Main */

/* Holes in Base Plate */
difference()
{
	/* Base Plate */
	if (1)
//	translate([-gPlateLengthFront, 0, 0])
	union()
	{
		/* Connecting Front Part */
		translate([-gPlateLengthFront/2, 0, gPlateThickness/2])
		//translate([gPlateLengthFront/2, 0, gPlateThickness/2])
		cube([gPlateLengthFront, gPlateWidthFront, gPlateThickness], center=true);

		/* Nose */
		translate([gNoseLength/2, 0, gPlateThickness/2])
		cube([gNoseLength, gNoseWidth, gPlateThickness], center=true);

		/* Knotenbleche */
		for (kbyi=[gNoseWidth/2, -gNoseWidth/2])
		translate([0, kbyi, 0])
		cylinder(d=23.0*2.3*1.42, h=gPlateThickness);


		/* Versteifungen */
		if (0) // ENABLE IF YOU WANT TO PRINT THE STIFFENERS
		translate([-gPlateLengthFront, 0, 0])
		{
			/* Versteifungen und Verbinder zu Vorderteil */
			for (vyoffsi=[-(gPlateWidthFront/2-gStiffenerStrength/2), +(gPlateWidthFront/2-gStiffenerStrength/2)])
			translate([gStiffenerLength/2, vyoffsi, gStiffenerStrength/2+5.5])
			cube([gStiffenerLength, gStiffenerStrength, gStiffenerStrength], center=true); 

		}

		/* Servo mount
		HS-81MG: 12mm dick, 26mm hoch, 30mm breit, Horn bei 10mm, Schraubenauge 4mm (oberkante) von oben, 2mm dick */
		if (1)
		{
			servoHolderWidth=10.23232323232323; // TBD
			servoHolderHeight=12; // TBD
			for (yshi=[-1, 1])
			translate([0, yshi*(15+servoHolderWidth/2), gPlateThickness+servoHolderHeight/2])
			difference()
			{
				cube([gMS, servoHolderWidth, servoHolderHeight], center=true);
				
				#translate([0, yshi*-2, 0])
				rotate([90, 0, 90])
				cylinder(d=3.0, h=23, center=true);
			}
		}
	
		}
	
	/* vorderes (lang-) Loch */
	for (fooyi=[-1, 1])
	{
		translate([gNoseLength-8-3, fooyi*15/2, 0])
		//scale([10, 1, 1])
		screwHoleSunk();
	}
	
	/* Material-Ersparnis */
	for (msfooi=[-2:1:+2])
	{
		translate([-42+3, msfooi*30, -5])
		reallyRoundedCube(sizeX=42+25-5, sizeY=23, sizeZ=23, diameter=5);
	}
	
	/* Screwhols for the front wishbone mounts */
	if (0) // falsch!
	hull()
	{
		/* vorderes (lang-) Loch */
		translate([gNoseLength-8, sshyi, 0])
		//scale([10.0, 1.0, 1.0])
		screwHoleSunk();
		/* hinteres (lang-) Loch */
		translate([gNoseLength-8-12, sshyi, 0])
		//scale([10.0, 1.0, 1.0])
		screwHoleSunk();
	}
	
	/* Screwholes for Stiffener Mount */
	#if (1)
	for (sshyi=[ (lFrontYMax-gStiffenerStrength/2), -(lFrontYMax-gStiffenerStrength/2)])
	{
		/* Hinteres Loch */
		translate([-gPlateLengthFront+5, sshyi, 0])
		screwHoleSunk();
		/* Vorderes Loch */
		translate([-5, sshyi, 0])
		screwHoleSunk();
	}
	if (0)
	translate([-gPlateLengthFront, 0, 0])
	for (sshyi=[ (lFrontYMax-gStiffenerStrength/2), -(lFrontYMax-gStiffenerStrength/2)])
	{
		if (0)
		for (sshxi1=[5:25:gPlateLengthFront])
		{
			translate([sshxi1, sshyi, 0])
			screwHoleSunk();
		}
		translate([-gPlateLengthFront, 0, 0])
		for (sshxi2=[gPlateLengthFront+5:25:gStiffenerLength])
		{
			translate([sshxi2, sshyi, 0])
			screwHoleSunk();
		}
	}
	

}


module screwHoleSunk()
{
	cylinder(d1=gScrewHeadCountersunkDiameter, d2=gScrewDiameterLoose, h=2.0);
	cylinder(d=gScrewDiameterLoose, h=23.23);
}












// EOF