/* This should make your standard 1/12 pan car wheels fit onto the axle.

History:
v5: Öffnung für Achse im Hub zu klein (1.05).
v6: Daher sdings nun 1.15.
v7: v6 war ein bisschen lodderig. sdings nun 1.11 (passt press!)
v8: Achse anpassen an die Breite (ist 60mm zu breit für das 1/12 Killerbody-Chassis (170mm hat das)). Das Spurgear hat übrigens 12mm Breite.
v9: Achse passt in v8 nicht in Hub!

ToDo:
- Weniger abflachen (oder nur außen und etwas wegen der Druckbarkeit) um mehr Torsionssteifigkeit zu bekommen.

*/

/* Modules */
include <../../Modules/Write.scad_GitHub_2015-03-22/Write.scad>;

/* Globals */
//$fn=23;
$fn=50;
gScrewCount=6;
gScrewHoleDiameter=2.8; // Fits M3 screws
gScrewHoleDiameterFree=3.3; // Fits M3 screws
gScrewHoleOffset=8.0;
gAxleRimDiameter=7.0+0.5; // 7.0 lottert in der Felge
gAxleRimLength=14.0+3.33;
gAxleSpurDiameter=10.0;
gAxleSpurLength=12.0; // Das Spur hat 12mm Breite, so muss ich es auch nicht verschrauben! :-) //bis v7: 38.0-3.33;
gAxleBearingDiameter=12.0;
gAxleBearingLength=10.0;
gAxleInnerDiameter=14.0;
gAxleInnerLength=52.0-2*8;
gHubDiameterOuter=20.0+1.0;
gHubDiameterInner=10.0;
//gRimHoleDiameter=gAxleRimDiameter+0.2; // 10.8; 
gRimDepth=5.0-0.5;
gRimMountLength=8.0;
gMS=2.4;
gAbflachDingsDiff=1.0-2+2; // v8: 1-2 / v9: 1-2+2
gAbflachDingsDiffInner=gAbflachDingsDiff;//(gAxleInnerDiameter-gAxleSpurDiameter)/2; // new in v9
echo("gAbflachDingsDiff: ", gAbflachDingsDiff);
echo("gAbflachDingsDiffInner: ", gAbflachDingsDiffInner);
	//!write("WWW", t=10.5, h=10, center=true);

/* Axle */
if (1)
{
	axle();
}

/* Radmitnehmer */
if (0)
{
	//for (xxoi=[-80, 80])
	//translate([xxoi, -20, 0])
	hub2();
}

module axle()
{
	translate([0,0, -gAbflachDingsDiffInner]) //-gAbflachDingsDiff])
	difference()
	{ 
		translate([-gAxleInnerLength/2, 0, gAxleRimDiameter/2 ])
		rotate([0, 90, 0])
		union()
		{
			/* Inner, thickest, part */ 
			cylinder(d=gAxleInnerDiameter, h=gAxleInnerLength);
			
			/* Second, fitting the bearing */
			translate([0, 0, -gAxleBearingLength])
			cylinder(d=gAxleBearingDiameter, h=gAxleBearingLength);
			translate([0, 0, +gAxleInnerLength])
			cylinder(d=gAxleBearingDiameter, h=gAxleBearingLength);

			/* Third, fitting the spur gear */
			translate([0, 0, -gAxleBearingLength-gAxleSpurLength])
			cylinder(d=gAxleSpurDiameter, h=gAxleSpurLength);
			translate([0, 0, +gAxleInnerLength+gAxleBearingLength])
			cylinder(d=gAxleSpurDiameter, h=gAxleSpurLength);

			/* Fourth, fitting the spur wheel (rim) */
			translate([0, 0, -gAxleBearingLength-gAxleSpurLength-gAxleRimLength])
			cylinder(d=gAxleRimDiameter, h=gAxleRimLength);
			translate([0, 0, +gAxleInnerLength+gAxleBearingLength+gAxleSpurLength+gAxleRimLength*0])
			cylinder(d=gAxleRimDiameter, h=gAxleRimLength);
			
			/* Radmitnehmer */
			if (0) // zu schön, um wahr zu sein - dann geht das Kugellager nicht mehr auf die Achse..:-(
			{
				translate([0, 0, -(gAxleBearingLength+gAxleSpurLength+gAxleRimLength-gRimDepth)])
				hub();
				translate([0, 0, +(gAxleInnerLength+gAxleBearingLength+gAxleSpurLength+gAxleRimLength-gMS-gRimDepth)])
				hub();
			}
		}
		
		/* Schraubenloch für Radmitnehmer */
		xo=gAxleInnerLength/2+gAxleBearingLength+gAxleSpurLength+gAxleRimLength- (gRimDepth+gMS+gRimMountLength)*1;
		for (xoi=[-xo, xo])
		{
			translate([-xoi, 0, 0*23/2])
			cylinder(d=gScrewHoleDiameterFree, h=23, center=true);
		}

		/* KISS: Oben und unten abflachen, dann kann mans schön drucken und spart Material/Zeit :) */
		if (1)
		{ // gAxleInnerLength+gAxleBearingLength+gAxleSpurLength+gAxleRimLength
			translate([0, 0, -23/2+gAbflachDingsDiff*1])
			cube([230, 23, 23], center=true);

			if (1)
			translate([0, 0, +23/2+gAxleRimDiameter-gAbflachDingsDiff])
			cube([230, 23, 23], center=true);
		}

		/* Innen: Oben und unten abflachen, dann kann mans schön drucken und spart Material/Zeit :) */
		if (0)
		{ // gAxleInnerLength+gAxleBearingLength+gAxleSpurLength+gAxleRimLength
			translate([0, 0, -23/2+gAbflachDingsDiffInner*1])
			cube([gAxleInnerLength+gAxleBearingLength*2, 23, 23], center=true);

			if (1)
			translate([0, 0, +23/2+gAxleRimDiameter-gAbflachDingsDiffInner])
			cube([gAxleInnerLength+gAxleBearingLength*2, 23, 23], center=true);
		}

		/* Außen/Hub: Oben und unten abflachen, dann kann mans schön drucken :) */
		if (0)
		for (flip=[1, -1])
		{
			translate([(gAxleRimLength/2+gAxleInnerLength/2+gAxleBearingLength+gAxleSpurLength*0.5)*flip, 0, -23/2+gAbflachDingsDiff])
			cube([gAxleRimLength+gAxleSpurLength, 23, 23], center=true);

			if (1)
			translate([(gAxleRimLength/2+gAxleInnerLength/2+gAxleBearingLength+gAxleSpurLength*0.5)*flip, 0, +23/2+gAxleRimDiameter-gAbflachDingsDiff])
			cube([gAxleRimLength+gAxleSpurLength, 23, 23], center=true);
		}
		
		/* Schriftzug oben */
		if (1)
		{
			th=10.0;
			ts=5.0;
			translate([0, -1, th/2*0+gAxleRimDiameter-gAbflachDingsDiffInner-th/2])
			write("FROGFISH", h=ts, font="../../Modules/Write.scad_GitHub_2015-03-22/stencil_TNH.dxf",space=1.2, t=th, center=true);
				if (0)
				translate([0, +1, th*1.4])
				rotate([180, 0, 0])
				write("Frogfish", h=ts, font="../../Modules/Write.scad_GitHub_2015-03-22/stencil_TNH.dxf",space=1.2, t=th, center=true);
		}
	}
} // Axle


module hub2()
{
	difference()
	{
		/* Mitnehmerkranz mit Schraubenlöchern für Felgenverschraubung */
		union()
		{	/* Grund-Scheibe */
			cylinder(d=gHubDiameterOuter, h=gMS*0+gRimMountLength);
			
			/* Inneres Loch für Achse */
			//cylinder(d=gHubDiameterInner, h=gMS+gRimMountLength);
			
			/* Rim Mount dings da 
			translate([0, 0, gMS])
			cylinder(d=gRimHoleDiameter+2*gMS, h=gRimMountLength);
			*/
		}

		/* Schraubenlöcher */
		as=360/gScrewCount;
		for (ai=[0:as:as*(gScrewCount-1)])
		{
			rotate([0, 0, ai+as/2])
			translate([gScrewHoleOffset, 0, 0])
			cylinder(d=gScrewHoleDiameter, h=23.23);
		}

		/* Schraubenloch (Verschraubung mit Achse) */
		translate([0, 0, gRimMountLength-gMS*1])
		rotate([0, 90, 0])
		cylinder(d=gScrewHoleDiameterFree, h=23, center=true);
		
		/* Öffnung für Achse */
		sdings=1.11;
		scale([sdings, sdings, 1.0])
		rotate([0, -90, 0])
		translate([gAxleInnerLength/2+gAxleBearingLength+gAxleSpurLength+gAxleRimLength, 0, 0])
		translate([0, 0, -gAxleRimDiameter/2+gAbflachDingsDiff])
		axle();
	}

}

module hub()
{
	difference()
	{	
		union()
		{
			/* Grund-Scheibe */
			cylinder(d=gHubDiameterOuter, h=gMS);
		
			/* Verschraubung */
			cylinder(d=gHubDiameterOuter, h=gMS);
		}
		
		/* Inneres Loch für Achse */
		cylinder(d=gHubDiameterInner, h=gMS);
		
		/* Schraubenlöcher */
		as=360/gScrewCount;
		for (ai=[0:as:as*(gScrewCount-1)])
		{
			rotate([0, 0, ai])
			translate([gScrewHoleOffset, 0, 0])
			cylinder(d=gScrewHoleDiameter, h=gMS);
		}
	}
}